@@ -1,3 +1,4 @@
+import sys
 import datetime
 import time
 from unittest import skipIf, mock
@@ -9,6 +10,7 @@ from django.core.management import call_command
 from django.test import TestCase, override_settings
 from django.urls import reverse
 
+from redis.exceptions import ConnectionError
 from rq import get_current_job, Queue
 from rq.exceptions import NoSuchJobError
 from rq.job import Job
@@ -17,6 +19,7 @@ from rq.worker import Worker
 
 from django_rq.decorators import job
 from django_rq.jobs import get_job_class
+from django_rq.management.commands import rqworker
 from django_rq.queues import (
     get_connection, get_queue, get_queues,
     get_unique_connection_configs, DjangoRQ,
@@ -89,6 +92,15 @@ class RqStatsTest(TestCase):
 @override_settings(RQ={'AUTOCOMMIT': True})
 class QueuesTest(TestCase):
 
+    def setUp(self):
+        """Used to test with / without sentry_sdk available."""
+        self.mock_sdk = mock.MagicMock()
+        self.mock_sdk.Hub.current.client.options = {}
+        sys.modules["sentry_sdk"] = self.mock_sdk
+
+    def tearDown(self):
+        del sys.modules["sentry_sdk"]
+
     def test_get_connection_default(self):
         """
         Test that get_connection returns the right connection based for
@@ -266,30 +278,75 @@ class QueuesTest(TestCase):
             self.assertTrue(job['job'].is_finished)
             self.assertIn(job['job'].id, job['finished_job_registry'].get_job_ids())
 
-    @mock.patch('rq.contrib.sentry.register_sentry')
-    def test_sentry_dsn(self, mocked):
+    def test_configure_sentry(self):
+        rqworker.configure_sentry('https://1@sentry.io/1')
+        self.mock_sdk.init.assert_called_once_with(
+            'https://1@sentry.io/1',
+            ca_certs=None,
+            debug=False,
+            integrations=[
+                self.mock_sdk.integrations.redis.RedisIntegration(),
+                self.mock_sdk.integrations.rq.RqIntegration(),
+                self.mock_sdk.integrations.django.DjangoIntegration(),
+            ]
+        )
+
+    def test_configure_sentry__options(self):
+        """Check that debug and ca_certs can be passed through to Sentry."""
+        rqworker.configure_sentry('https://1@sentry.io/1', sentry_debug=True, sentry_ca_certs='/certs')
+        self.mock_sdk.init.assert_called_once_with(
+            'https://1@sentry.io/1',
+            ca_certs='/certs',
+            debug=True,
+            integrations=[
+                self.mock_sdk.integrations.redis.RedisIntegration(),
+                self.mock_sdk.integrations.rq.RqIntegration(),
+                self.mock_sdk.integrations.django.DjangoIntegration(),
+            ]
+        )
+
+    def test_sentry_dsn(self):
+        """Check that options are passed to configure_sentry as expected."""
         queue_names = ['django_rq_test']
         call_command('rqworker', *queue_names, burst=True,
-                     sentry_dsn='https://1@sentry.io/1')
+                     sentry_dsn='https://1@sentry.io/1', sentry_debug=True, sentry_ca_certs='/certs')
 
-        self.assertEqual(mocked.call_count, 1)
+        self.mock_sdk.init.assert_called_once_with(
+            'https://1@sentry.io/1',
+            ca_certs='/certs',
+            debug=True,
+            integrations=[
+                self.mock_sdk.integrations.redis.RedisIntegration(),
+                self.mock_sdk.integrations.rq.RqIntegration(),
+                self.mock_sdk.integrations.django.DjangoIntegration(),
+            ]
+        )
 
-    @mock.patch('rq.contrib.sentry.register_sentry')
-    def test_sentry_dsn_setting(self, mocked):
+    @mock.patch('django_rq.management.commands.rqworker.configure_sentry')
+    def test_sentry_dsn__noop(self, mocked):
+        """Check that sentry is ignored if sentry_dsn is not passed in."""
         queue_names = ['django_rq_test']
-        with self.settings(SENTRY_DSN='https://1@sentry.io/1'):
-            call_command('rqworker', *queue_names, burst=True)
+        call_command('rqworker', *queue_names, burst=True,
+                     sentry_debug=True, sentry_ca_certs='/certs')
 
-            self.assertEqual(mocked.call_count, 1)
+        self.assertEqual(mocked.call_count, 0)
 
-    @mock.patch('rq.contrib.sentry.register_sentry')
-    def test_sentry_dsn_setting_override(self, mocked):
+    @mock.patch('django_rq.management.commands.rqworker.configure_sentry')
+    def test_sentry_sdk_import_error(self, mocked):
+        """Check the command handles import errors as expected."""
+        mocked.side_effect = ImportError
         queue_names = ['django_rq_test']
-        with self.settings(SENTRY_DSN='https://1@sentry.io/1'):
+        with self.assertRaises(SystemExit):
             call_command('rqworker', *queue_names, burst=True,
-                         sentry_dsn='')
+                         sentry_dsn='https://1@sentry.io/1')
 
-            self.assertEqual(mocked.call_count, 0)
+    @mock.patch('django_rq.management.commands.rqworker.use_connection')
+    def test_connection_error(self, mocked):
+        """Check that redis ConnectionErrors are handled correctly."""
+        mocked.side_effect = ConnectionError("Unable to connect")
+        queue_names = ['django_rq_test']
+        with self.assertRaises(SystemExit):
+            call_command('rqworker', *queue_names)
 
     def test_get_unique_connection_configs(self):
         connection_params_1 = {
@@ -440,6 +497,14 @@ class DecoratorTest(TestCase):
         self.assertEqual(result.result_ttl, 5432)
         result.delete()
 
+    @override_settings(RQ={'AUTOCOMMIT': True, 'DEFAULT_RESULT_TTL': 0})
+    def test_job_decorator_result_ttl_zero(self):
+        @job
+        def test():
+            pass
+        result = test.delay()
+        self.assertEqual(result.result_ttl, 0)
+        result.delete()
 
 @override_settings(RQ={'AUTOCOMMIT': True})
 class WorkersTest(TestCase):
@@ -788,4 +853,4 @@ class UtilsTest(TestCase):
             get_jobs(queue, [job.id, job2.id], registry),
             []
         )
-        self.assertEqual(len(registry), 0)
\ No newline at end of file
+        self.assertEqual(len(registry), 0)
